@@ -6,6 +6,7 @@ from platform import uname
 from uuid import getnode
 
 from plexapi.config import PlexConfig, reset_base_headers
+import plexapi.const as const
 from plexapi.utils import SecretsFilter
 
 # Load User Defined Config
@@ -15,7 +16,7 @@ CONFIG = PlexConfig(CONFIG_PATH)
 
 # PlexAPI Settings
 PROJECT = 'PlexAPI'
-VERSION = '4.0.0'
+VERSION = __version__ = const.__version__
 TIMEOUT = CONFIG.get('plexapi.timeout', 30, int)
 X_PLEX_CONTAINER_SIZE = CONFIG.get('plexapi.container_size', 100, int)
 X_PLEX_ENABLE_FAST_CONNECT = CONFIG.get('plexapi.enable_fast_connect', False, bool)
