@@ -24,6 +24,8 @@ class PlexClient(PlexObject):
             data (ElementTree): Response from PlexServer used to build this object (optional).
             initpath (str): Path used to generate data.
             baseurl (str): HTTP URL to connect dirrectly to this client.
+            identifier (str): The resource/machine identifier for the desired client.
+                May be necessary when connecting to a specific proxied client (optional).
             token (str): X-Plex-Token used for authenication (optional).
             session (:class:`~requests.Session`): requests.Session object if you want more control (optional).
             timeout (int): timeout in seconds on initial connect to client (default config.TIMEOUT).
@@ -53,15 +55,16 @@ class PlexClient(PlexObject):
             _token (str): Token used to access this client.
             _session (obj): Requests session object used to access this client.
             _proxyThroughServer (bool): Set to True after calling
-                :func:`~plexapi.client.PlexClient.proxyThroughServer()` (default False).
+                :func:`~plexapi.client.PlexClient.proxyThroughServer` (default False).
     """
     TAG = 'Player'
     key = '/resources'
 
     def __init__(self, server=None, data=None, initpath=None, baseurl=None,
-          token=None, connect=True, session=None, timeout=None):
+          identifier=None, token=None, connect=True, session=None, timeout=None):
         super(PlexClient, self).__init__(server, data, initpath)
         self._baseurl = baseurl.strip('/') if baseurl else None
+        self._clientIdentifier = identifier
         self._token = logfilter.add_secret(token)
         self._showSecrets = CONFIG.get('log.show_secrets', '').lower() == 'true'
         server_session = server._session if server else None
@@ -69,7 +72,9 @@ class PlexClient(PlexObject):
         self._proxyThroughServer = False
         self._commandId = 0
         self._last_call = 0
-        if not any([data, initpath, baseurl, token]):
+        self._timeline_cache = []
+        self._timeline_cache_timestamp = 0
+        if not any([data is not None, initpath, baseurl, token]):
             self._baseurl = CONFIG.get('auth.client_baseurl', 'http://localhost:32433')
             self._token = logfilter.add_secret(CONFIG.get('auth.client_token'))
         if connect and self._baseurl:
@@ -88,7 +93,25 @@ class PlexClient(PlexObject):
             raise Unsupported('Cannot reload an object not built from a URL.')
         self._initpath = self.key
         data = self.query(self.key, timeout=timeout)
-        self._loadData(data[0])
+        if not data:
+            raise NotFound("Client not found at %s" % self._baseurl)
+        if self._clientIdentifier:
+            client = next(
+                (
+                    x
+                    for x in data
+                    if x.attrib.get("machineIdentifier") == self._clientIdentifier
+                ),
+                None,
+            )
+            if client is None:
+                raise NotFound(
+                    "Client with identifier %s not found at %s"
+                    % (self._clientIdentifier, self._baseurl)
+                )
+        else:
+            client = data[0]
+        self._loadData(client)
         return self
 
     def reload(self):
@@ -138,7 +161,7 @@ class PlexClient(PlexObject):
                 value (bool): Enable or disable proxying (optional, default True).
 
             Raises:
-                :class:`plexapi.exceptions.Unsupported`: Cannot use client proxy with unknown server.
+                :exc:`~plexapi.exceptions.Unsupported`: Cannot use client proxy with unknown server.
         """
         if server:
             self._server = server
@@ -171,7 +194,7 @@ class PlexClient(PlexObject):
         return ElementTree.fromstring(data) if data.strip() else None
 
     def sendCommand(self, command, proxy=None, **params):
-        """ Convenience wrapper around :func:`~plexapi.client.PlexClient.query()` to more easily
+        """ Convenience wrapper around :func:`~plexapi.client.PlexClient.query` to more easily
             send simple commands to the client. Returns an ElementTree object containing
             the response.
 
@@ -181,7 +204,7 @@ class PlexClient(PlexObject):
                 **params (dict): Additional GET parameters to include with the command.
 
             Raises:
-                :class:`plexapi.exceptions.Unsupported`: When we detect the client doesn't support this capability.
+                :exc:`~plexapi.exceptions.Unsupported`: When we detect the client doesn't support this capability.
         """
         command = command.strip('/')
         controller = command.split('/')[0]
@@ -199,7 +222,7 @@ class PlexClient(PlexObject):
             self._last_call = t
         elif t - self._last_call >= 80 and self.product in ('ptp', 'Plex Media Player'):
             self._last_call = t
-            self.timeline(wait=0)
+            self.sendCommand(ClientTimeline.key, wait=0)
 
         params['commandID'] = self._nextCommandId()
         key = '/player/%s%s' % (command, utils.joinArgs(params))
@@ -297,7 +320,7 @@ class PlexClient(PlexObject):
                 **params (dict): Additional GET parameters to include with the command.
 
             Raises:
-                :class:`plexapi.exceptions.Unsupported`: When no PlexServer specified in this object.
+                :exc:`~plexapi.exceptions.Unsupported`: When no PlexServer specified in this object.
         """
         if not self._server:
             raise Unsupported('A server must be specified before using this command.')
@@ -467,7 +490,7 @@ class PlexClient(PlexObject):
                     also: https://github.com/plexinc/plex-media-player/wiki/Remote-control-API#modified-commands
 
             Raises:
-                :class:`plexapi.exceptions.Unsupported`: When no PlexServer specified in this object.
+                :exc:`~plexapi.exceptions.Unsupported`: When no PlexServer specified in this object.
         """
         if not self._server:
             raise Unsupported('A server must be specified before using this command.')
@@ -488,11 +511,13 @@ class PlexClient(PlexObject):
 
         playqueue = media if isinstance(media, PlayQueue) else self._server.createPlayQueue(media)
         self.sendCommand('playback/playMedia', **dict({
+            'providerIdentifier': 'com.plexapp.plugins.library',
             'machineIdentifier': self._server.machineIdentifier,
+            'protocol': server_url[0],
             'address': server_url[1].strip('/'),
             'port': server_port,
             'offset': offset,
-            'key': media.key,
+            'key': media.key or playqueue.selectedItem.key,
             'token': media._server.createToken(),
             'type': mediatype,
             'containerKey': '/playQueues/%s?window=100&own=1' % playqueue.playQueueID,
@@ -540,20 +565,68 @@ class PlexClient(PlexObject):
 
     # -------------------
     # Timeline Commands
-    def timeline(self, wait=1):
-        """ Poll the current timeline and return the XML response. """
-        return self.sendCommand('timeline/poll', wait=wait)
+    def timelines(self, wait=0):
+        """Poll the client's timelines, create, and return timeline objects.
+           Some clients may not always respond to timeline requests, believe this
+           to be a Plex bug.
+        """
+        t = time.time()
+        if t - self._timeline_cache_timestamp > 1:
+            self._timeline_cache_timestamp = t
+            timelines = self.sendCommand(ClientTimeline.key, wait=wait) or []
+            self._timeline_cache = [ClientTimeline(self, data) for data in timelines]
 
-    def isPlayingMedia(self, includePaused=False):
-        """ Returns True if any media is currently playing.
+        return self._timeline_cache
+
+    @property
+    def timeline(self):
+        """Returns the active timeline object."""
+        return next((x for x in self.timelines() if x.state != 'stopped'), None)
+
+    def isPlayingMedia(self, includePaused=True):
+        """Returns True if any media is currently playing.
 
             Parameters:
                 includePaused (bool): Set True to treat currently paused items
-                    as playing (optional; default True).
+                                      as playing (optional; default True).
         """
-        for mediatype in self.timeline(wait=0):
-            if mediatype.get('state') == 'playing':
-                return True
-            if includePaused and mediatype.get('state') == 'paused':
-                return True
-        return False
+        state = getattr(self.timeline, "state", None)
+        return bool(state == 'playing' or (includePaused and state == 'paused'))
+
+
+class ClientTimeline(PlexObject):
+    """Get the timeline's attributes."""
+
+    key = 'timeline/poll'
+
+    def _loadData(self, data):
+        self._data = data
+        self.address = data.attrib.get('address')
+        self.audioStreamId = utils.cast(int, data.attrib.get('audioStreamId'))
+        self.autoPlay = utils.cast(bool, data.attrib.get('autoPlay'))
+        self.containerKey = data.attrib.get('containerKey')
+        self.controllable = data.attrib.get('controllable')
+        self.duration = utils.cast(int, data.attrib.get('duration'))
+        self.itemType = data.attrib.get('itemType')
+        self.key = data.attrib.get('key')
+        self.location = data.attrib.get('location')
+        self.machineIdentifier = data.attrib.get('machineIdentifier')
+        self.partCount = utils.cast(int, data.attrib.get('partCount'))
+        self.partIndex = utils.cast(int, data.attrib.get('partIndex'))
+        self.playQueueID = utils.cast(int, data.attrib.get('playQueueID'))
+        self.playQueueItemID = utils.cast(int, data.attrib.get('playQueueItemID'))
+        self.playQueueVersion = utils.cast(int, data.attrib.get('playQueueVersion'))
+        self.port = utils.cast(int, data.attrib.get('port'))
+        self.protocol = data.attrib.get('protocol')
+        self.providerIdentifier = data.attrib.get('providerIdentifier')
+        self.ratingKey = utils.cast(int, data.attrib.get('ratingKey'))
+        self.repeat = utils.cast(bool, data.attrib.get('repeat'))
+        self.seekRange = data.attrib.get('seekRange')
+        self.shuffle = utils.cast(bool, data.attrib.get('shuffle'))
+        self.state = data.attrib.get('state')
+        self.subtitleColor = data.attrib.get('subtitleColor')
+        self.subtitlePosition = data.attrib.get('subtitlePosition')
+        self.subtitleSize = utils.cast(int, data.attrib.get('subtitleSize'))
+        self.time = utils.cast(int, data.attrib.get('time'))
+        self.type = data.attrib.get('type')
+        self.volume = utils.cast(int, data.attrib.get('volume'))
